import {useRef, useState} from "react";
import Button from "./Button";
import {createTournament} from "../features/tournament/services";


export default function TournamentForm({setIsOpen}) {

    const [tournamentName, setTournamentName] = useState('')
    const [teamName, setTeamName] = useState('')
    const [teamNames, setTeamNames] = useState([])


    const handleOnChange = (event, set) => {
        set(event.target.value);

    }

    const handleOnKeyDown = (event) => {
        if (event.key === 'Enter') {
            event.preventDefault()
            setTeamNames([...teamNames, teamName])
            setTeamName('');
        }
    }
    const handleRemoveTeam = (index) => {
        setTeamNames(teamNames.filter((teamName, i) => i !== index))
    }


    const handleSubmit = async (event) => {
        event.preventDefault()
        const tournament = {
            tournamentName: tournamentName,
            teamNames: teamNames
        }
        try {
            await createTournament(tournament)
            setIsOpen(false);
            setTournamentName('')
            setTeamName('')
            setTeamNames([])
        } catch (e) {

        }

    }

    return (
        <div className={'w-[40vw]'}>
            <button className={'absolute top-0 right-0 m-1'}
                    onClick={() => setIsOpen(false)}>❌
            </button>
            <form className={'flex flex-col'} onSubmit={handleSubmit}>
                <label htmlFor='tournamentName'>Tournament Name</label>
                <input type='text' id='tournamentName' value={tournamentName}
                       onChange={(event) => handleOnChange(event, setTournamentName)}/>
                <label htmlFor='teamNames'>Team Name</label>
                <input type='text' id='teamNames' value={teamName}
                       onChange={(event) => handleOnChange(event, setTeamName)}
                       onKeyDown={handleOnKeyDown}/>
                <input className={'bg-green-700'} type='submit'/>
                <ul>
                    {teamNames.map((teamName, index) => <li key={index}>
                        <div>
                            {teamName}
                            <Button onClick={() => handleRemoveTeam(index)}>Remove</Button>
                        </div>
                    </li>)}
                </ul>
            </form>
        </div>
    )
}
